Troubleshooting — Django Grappelli 2.7.3 documentation

# Troubleshooting

Sometimes you might have a problem installing/using Grappelli.

## Check your setup

First, please check if the problem is caused by your setup.

- Read Quick start guide and Customization.
- Check if the static/media files are served correctly.
- Make sure you have removed all customized admin templates from all locations in `TEMPLATE_DIRS` paths or check that these templates are compatible with Grappelli.

## Check issues

If your setup is fine, please check if your problem is a known issue.

- Read Django Issues in order to see if your problem is indeed related to Grappelli.
- Take a look at all Grappelli Issues (incuding closed) and search the Grappelli Google-Group.

## Add a ticket

If you think you’ve found a bug, please add a ticket and follow the guidelines for contributing.